@@ -489,14 +489,14 @@ mod hz_tests {
     #[test]
     fn test_encoder_valid() {
         let mut e = HZEncoding.raw_encoder();
-        assert_feed_ok!(e, "A", "", b"A");
-        assert_feed_ok!(e, "BC", "", b"BC");
-        assert_feed_ok!(e, "", "", b"");
+        assert_feed_ok!(e, "A", "", *b"A");
+        assert_feed_ok!(e, "BC", "", *b"BC");
+        assert_feed_ok!(e, "", "", *b"");
         assert_feed_ok!(e, "\u{4e2d}\u{534e}\u{4eba}\u{6c11}\u{5171}\u{548c}\u{56fd}", "",
-                        b"~{VP;*HKCq92:M9z");
-        assert_feed_ok!(e, "\u{ff21}\u{ff22}\u{ff23}", "", b"#A#B#C");
-        assert_feed_ok!(e, "1\u{20ac}/m", "", b"~}1~{\"c~}/m");
-        assert_feed_ok!(e, "~<\u{a4}~\u{0a4}>~", "", b"~~<~{!h~}~~~{!h~}>~~");
+                        *b"~{VP;*HKCq92:M9z");
+        assert_feed_ok!(e, "\u{ff21}\u{ff22}\u{ff23}", "", *b"#A#B#C");
+        assert_feed_ok!(e, "1\u{20ac}/m", "", *b"~}1~{\"c~}/m");
+        assert_feed_ok!(e, "~<\u{a4}~\u{0a4}>~", "", *b"~~<~{!h~}~~~{!h~}>~~");
         assert_finish_ok!(e, []);
     }
 
@@ -513,33 +513,33 @@ mod hz_tests {
     #[test]
     fn test_decoder_valid() {
         let mut d = HZEncoding.raw_decoder();
-        assert_feed_ok!(d, b"A", b"", "A");
-        assert_feed_ok!(d, b"BC", b"", "BC");
-        assert_feed_ok!(d, b"D~~E", b"~", "D~E");
-        assert_feed_ok!(d, b"~F~\nG", b"~", "~FG");
-        assert_feed_ok!(d, b"", b"", "");
-        assert_feed_ok!(d, b"\nH", b"~", "H");
-        assert_feed_ok!(d, b"{VP~}~{;*~{HKCq92:M9z", b"",
+        assert_feed_ok!(d, *b"A", *b"", "A");
+        assert_feed_ok!(d, *b"BC", *b"", "BC");
+        assert_feed_ok!(d, *b"D~~E", *b"~", "D~E");
+        assert_feed_ok!(d, *b"~F~\nG", *b"~", "~FG");
+        assert_feed_ok!(d, *b"", *b"", "");
+        assert_feed_ok!(d, *b"\nH", *b"~", "H");
+        assert_feed_ok!(d, *b"{VP~}~{;*~{HKCq92:M9z", *b"",
                         "\u{4e2d}\u{534e}\u{4eba}\u{6c11}\u{5171}\u{548c}\u{56fd}");
-        assert_feed_ok!(d, b"", b"#", "");
-        assert_feed_ok!(d, b"A", b"~", "\u{ff21}");
-        assert_feed_ok!(d, b"~#B~~#C", b"~", "~\u{ff22}~\u{ff23}");
-        assert_feed_ok!(d, b"", b"", "");
-        assert_feed_ok!(d, b"\n#D~{#E~\n#F~{#G", b"~", "#D\u{ff25}#F\u{ff27}");
-        assert_feed_ok!(d, b"}X~}YZ", b"", "XYZ");
+        assert_feed_ok!(d, *b"", *b"#", "");
+        assert_feed_ok!(d, *b"A", *b"~", "\u{ff21}");
+        assert_feed_ok!(d, *b"~#B~~#C", *b"~", "~\u{ff22}~\u{ff23}");
+        assert_feed_ok!(d, *b"", *b"", "");
+        assert_feed_ok!(d, *b"\n#D~{#E~\n#F~{#G", *b"~", "#D\u{ff25}#F\u{ff27}");
+        assert_feed_ok!(d, *b"}X~}YZ", *b"", "XYZ");
         assert_finish_ok!(d, "");
     }
 
     #[test]
     fn test_decoder_invalid_out_or_range() {
         let mut d = HZEncoding.raw_decoder();
-        assert_feed_ok!(d, b"~{", b"", "");
-        assert_feed_err!(d, b"", b"\x20\x20", b"", "");
-        assert_feed_err!(d, b"", b"\x20\x7f", b"", ""); // do not reset the state (except for CR)
-        assert_feed_err!(d, b"", b"\x21\x7f", b"", "");
-        assert_feed_err!(d, b"", b"\x7f\x20", b"", "");
-        assert_feed_err!(d, b"", b"\x7f\x21", b"", "");
-        assert_feed_err!(d, b"", b"\x7f\x7f", b"", "");
+        assert_feed_ok!(d, *b"~{", *b"", "");
+        assert_feed_err!(d, *b"", *b"\x20\x20", *b"", "");
+        assert_feed_err!(d, *b"", *b"\x20\x7f", *b"", ""); // do not reset the state (except for CR)
+        assert_feed_err!(d, *b"", *b"\x21\x7f", *b"", "");
+        assert_feed_err!(d, *b"", *b"\x7f\x20", *b"", "");
+        assert_feed_err!(d, *b"", *b"\x7f\x21", *b"", "");
+        assert_feed_err!(d, *b"", *b"\x7f\x7f", *b"", "");
         assert_finish_ok!(d, "");
     }
 
@@ -547,52 +547,52 @@ mod hz_tests {
     fn test_decoder_invalid_carriage_return() {
         // CR in the multibyte mode is invalid but *also* resets the state
         let mut d = HZEncoding.raw_decoder();
-        assert_feed_ok!(d, b"~{#A", b"", "\u{ff21}");
-        assert_feed_err!(d, b"", b"\n", b"", "");
-        assert_feed_ok!(d, b"#B~{#C", b"", "#B\u{ff23}");
-        assert_feed_err!(d, b"", b"#\n", b"", "");
-        assert_feed_ok!(d, b"#D", b"", "#D");
+        assert_feed_ok!(d, *b"~{#A", *b"", "\u{ff21}");
+        assert_feed_err!(d, *b"", *b"\n", *b"", "");
+        assert_feed_ok!(d, *b"#B~{#C", *b"", "#B\u{ff23}");
+        assert_feed_err!(d, *b"", *b"#\n", *b"", "");
+        assert_feed_ok!(d, *b"#D", *b"", "#D");
         assert_finish_ok!(d, "");
     }
 
     #[test]
     fn test_decoder_invalid_partial() {
         let mut d = HZEncoding.raw_decoder();
-        assert_feed_ok!(d, b"", b"~", "");
+        assert_feed_ok!(d, *b"", *b"~", "");
         assert_finish_err!(d, "");
 
         let mut d = HZEncoding.raw_decoder();
-        assert_feed_ok!(d, b"~{", b"#", "");
+        assert_feed_ok!(d, *b"~{", *b"#", "");
         assert_finish_err!(d, "");
 
         let mut d = HZEncoding.raw_decoder();
-        assert_feed_ok!(d, b"~{#A", b"~", "\u{ff21}");
+        assert_feed_ok!(d, *b"~{#A", *b"~", "\u{ff21}");
         assert_finish_err!(d, "");
     }
 
     #[test]
     fn test_decoder_invalid_escape() {
         let mut d = HZEncoding.raw_decoder();
-        assert_feed_ok!(d, b"#A", b"", "#A");
-        assert_feed_err!(d, b"", b"~", b"xy", "");
-        assert_feed_ok!(d, b"#B", b"", "#B");
-        assert_feed_ok!(d, b"", b"~", "");
-        assert_feed_err!(d, b"", b"", b"xy", "");
-        assert_feed_ok!(d, b"#C~{#D", b"", "#C\u{ff24}");
-        assert_feed_err!(d, b"", b"~", b"xy", "");
-        assert_feed_ok!(d, b"#E", b"", "\u{ff25}"); // does not reset to ASCII
-        assert_feed_ok!(d, b"", b"~", "");
-        assert_feed_err!(d, b"", b"", b"xy", "");
-        assert_feed_ok!(d, b"#F~}#G", b"", "\u{ff26}#G");
+        assert_feed_ok!(d, *b"#A", *b"", "#A");
+        assert_feed_err!(d, *b"", *b"~", *b"xy", "");
+        assert_feed_ok!(d, *b"#B", *b"", "#B");
+        assert_feed_ok!(d, *b"", *b"~", "");
+        assert_feed_err!(d, *b"", *b"", *b"xy", "");
+        assert_feed_ok!(d, *b"#C~{#D", *b"", "#C\u{ff24}");
+        assert_feed_err!(d, *b"", *b"~", *b"xy", "");
+        assert_feed_ok!(d, *b"#E", *b"", "\u{ff25}"); // does not reset to ASCII
+        assert_feed_ok!(d, *b"", *b"~", "");
+        assert_feed_err!(d, *b"", *b"", *b"xy", "");
+        assert_feed_ok!(d, *b"#F~}#G", *b"", "\u{ff26}#G");
         assert_finish_ok!(d, "");
     }
 
     #[test]
     fn test_decoder_feed_after_finish() {
         let mut d = HZEncoding.raw_decoder();
-        assert_feed_ok!(d, b"R;~{R;", b"R", "R;\u{4e00}");
+        assert_feed_ok!(d, *b"R;~{R;", *b"R", "R;\u{4e00}");
         assert_finish_err!(d, "");
-        assert_feed_ok!(d, b"R;~{R;", b"", "R;\u{4e00}");
+        assert_feed_ok!(d, *b"R;~{R;", *b"", "R;\u{4e00}");
         assert_finish_ok!(d, "");
     }
 
