@@ -162,8 +162,10 @@ pub static INVALID_UTF8_TEXT: &'static [u8] = include_bytes!("examples/UTF-8-tes
 /// This can be overriden with an environment variable `EXTERNAL_BENCH_DATA`,
 /// or it will use a built-in sample data (of about 100KB).
 pub fn get_external_bench_data() -> Vec<u8> {
-    use std::old_io as io;
     use std::env;
+    use std::io::Read;
+    use std::fs::File;
+    use std::path::Path;
 
     // An HTML file derived from the Outer Space Treaty of 1967, in six available languages.
     // http://www.unoosa.org/oosa/SpaceLaw/outerspt.html
@@ -171,9 +173,11 @@ pub fn get_external_bench_data() -> Vec<u8> {
 
     match env::var("EXTERNAL_BENCH_DATA") {
         Ok(path) => {
-            let path = Path::new(path);
-            let mut file = io::File::open(&path).ok().expect("cannot read an external bench data");
-            file.read_to_end().ok().expect("cannot read an external bench data")
+            let path = Path::new(&path);
+            let mut file = File::open(&path).ok().expect("cannot read an external bench data");
+            let mut ret = Vec::new();
+            file.read_to_end(&mut ret).ok().expect("cannot read an external bench data");
+            ret
         }
         Err(..) => {
             LONGER_TEXT.to_vec()
